@@ -3,11 +3,11 @@ get.PD.ratio <- function(tt,st,nuclide,exterr=TRUE,bratio=1){
     R <- bratio*(exp(L[1]*tt)-1)
     Jac <- matrix(0,1,2)
     E <- matrix(0,2,2)
-    Jac[1,1] <- tt*exp(L[1]*tt)
-    Jac[1,2] <- L[1]*exp(L[1]*tt)
-    E[1,1] <- L[2]^2
-    E[2,2] <- st^2
-    sR <- bratio*sqrt(Jac %*% E %*% t(Jac))
+    Jac[1,1] <- bratio*L[1]*exp(L[1]*tt)
+    if (exterr) Jac[1,2] <- bratio*tt*exp(L[1]*tt)
+    E[1,1] <- st^2
+    E[2,2] <- L[2]^2
+    sR <- sqrt(Jac %*% E %*% t(Jac))
     out <- c(R,sR)
 }
 
@@ -33,19 +33,27 @@ get.PD.age <- function(DP,sDP,nuclide,exterr=TRUE,bratio=1){
 PD.age <- function(x,nuclide,exterr=TRUE,i=NA,
                    sigdig=NA,i2i=TRUE,bratio=1,...){
     ns <- length(x)
-    if (ns<2) i2i <- FALSE
-    dat <- data2york(x,exterr=exterr)
-    if (i2i){
-        fit <- isochron(x,plot=FALSE,exterr=exterr)
-        initial <- fit$a
-    } else {
-        initial <- get.initial(x)
-    }
-    dat[,'Y'] <- dat[,'Y'] - initial[1]
-    if (exterr) dat[,'sY'] <- sqrt(dat[,'sY']^2 + initial[2]^2)
     out <- matrix(0,ns,2)
     colnames(out) <- c('t','s[t]')
-    DP <- quotient(dat[,'X'],dat[,'sX'],dat[,'Y'],dat[,'sY'],dat[,'rXY'])
+    if (ns<2) i2i <- FALSE
+    if (i2i){
+        y <- data2york(x,inverse=TRUE)
+        fit <- regression(y,model=1)
+        DP <- matrix(0,ns,2)
+        DP[,1] <- 1/(y[,'X'] - y[,'Y']/fit$b[1])
+        J1 <- -DP[,1]^2
+        J2 <- (DP[,1]^2)/fit$b[1]
+        E11 <- y[,'sX']^2
+        E22 <- y[,'sY']^2
+        E12 <- y[,'rXY']*y[,'sX']*y[,'sY']
+        DP[,2] <- errorprop1x2(J1,J2,E11,E22,E12)
+    } else {
+        initial <- get.nominal.initials(x)
+        dat <- data2york(x,exterr=exterr)
+        dat[,'Y'] <- dat[,'Y'] - initial$y0
+        DP <- quotient(dat[,'X'],dat[,'sX'],dat[,'Y'],dat[,'sY'],dat[,'rXY'])
+        if (exterr) dat[,'sY'] <- sqrt(dat[,'sY']^2 + initial$sy0^2)
+    }
     tt <- get.PD.age(subset(DP,select=1),subset(DP,select=2),
                      nuclide,exterr=exterr,bratio=bratio)
     out <- roundit(subset(tt,select=1),subset(tt,select=2),sigdig=sigdig)
@@ -53,7 +61,7 @@ PD.age <- function(x,nuclide,exterr=TRUE,i=NA,
     out
 }
 
-get.initial <- function(x){
+get.nominal.initials <- function(x){
     out <- c(0,0)
     if (hasClass(x,'RbSr')){
         out <- settings('iratio','Sr87Sr86')
@@ -68,7 +76,7 @@ get.initial <- function(x){
     } else if (hasClass(x,'KCa')){
         out <- settings('iratio','Ca40Ca44')
     }
-    out
+    list(y0=out[1],sy0=out[2])
 }
 
 ppm2ratios <- function(x,...){ UseMethod("ppm2ratios",x) }
@@ -76,4 +84,14 @@ ppm2ratios.default <- function(x,...){
     stop('Method ppm2ratios not available for this class.')
 }
 
-length.PD <- function(x,...){ nrow(x$x) }
+PD.inverse.ratios <- function(x,exterr=FALSE){
+    X <- PD.normal.ratios(x,exterr=exterr)
+    normal2inverse(X)
+}
+PD.normal.ratios <- function(x,exterr=FALSE){
+    if (x$format==1)
+        out <- x$x
+    else if (x$format==2)
+        out <- ppm2ratios(x,exterr=exterr)
+    out
+}
