@@ -17,7 +17,9 @@
 #' to other chronometers as well.
 #'
 #' @param x an object of class \code{UPb}
+#' 
 #' @param alpha cutoff value for confidence intervals
+#' 
 #' @param ... optional arguments
 #
 # @param x a \eqn{3n}-element vector \eqn{[X Y Z]}, where \eqn{X},
@@ -112,16 +114,14 @@ ludwig.default <- function(x,...){
 #'     \code{\link{isochron}}
 #' @rdname ludwig
 #' @export
-ludwig.UPb <- function(x,exterr=FALSE,alpha=0.05,model=1,
-                       anchor=list(FALSE,NA),...){
+ludwig.UPb <- function(x,exterr=FALSE,alpha=0.05,model=1,anchor=list(FALSE,NA),...){
     fit <- get.ta0b0(x,exterr=exterr,model=model,anchor=anchor)
     out <- fit[c('par','w','model')]
     out$cov <- fisher.lud(x,fit=fit,anchor=anchor)
     mswd <- mswd.lud(fit$par,x=x,anchor=anchor)
     out <- c(out,mswd)
     if (model==3){
-        out$w <- c(fit$w,
-                   profile_LL_discordia_disp(fit,x=x,alpha=alpha))
+        out$w <- c(fit$w,profile_LL_discordia_disp(fit,x=x,alpha=alpha))
         names(out$w) <- c('s','ll','ul')
     }
     if (x$format<4) parnames <- c('t[l]','76i')
@@ -155,8 +155,7 @@ mswd.lud <- function(ta0b0,x,anchor=list(FALSE,NA)){
     out
 }
 
-get.ta0b0 <- function(x,exterr=FALSE,model=1,
-                      anchor=list(FALSE,NA)){
+get.ta0b0 <- function(x,exterr=FALSE,model=1,anchor=list(FALSE,NA)){
     init <- get.ta0b0.model2(x,anchor=anchor)
     if (model==1)
         out <- get.ta0b0.model1(x,init=init,exterr=exterr,anchor=anchor)
@@ -169,18 +168,17 @@ get.ta0b0 <- function(x,exterr=FALSE,model=1,
     out
 }
 get.ta0b0.model1 <- function(x,init,exterr=FALSE,anchor=list(FALSE,NA)){
-    out <- fit_ludwig_discordia(x,init=init,w=0,exterr=exterr,
-                                fixed=fixit(x,anchor))
+    out <- fit_ludwig_discordia(x,init=init,w=0,exterr=exterr,anchor=anchor)
     out$w <- 0
     out
 }
 get.ta0b0.model2 <- function(x,anchor=list(FALSE,NA)){
-    xy <- data2york(x,wetherill=FALSE)[,c('X','Y')]
+    xy <- data2york(x,option=2)[,c('X','Y')]
     if (!anchor[[1]]) {
         xyfit <- stats::lm(xy[,'Y'] ~ xy[,'X'])
         intercept <- xyfit$coef[1]
         slope <- xyfit$coef[2]
-        ta0b0 <- concordia.intersection.ab(intercept,slope,wetherill=FALSE)$x
+        ta0b0 <- concordia.intersection.ab(intercept,slope,wetherill=FALSE,d=x$d)
     } else if (is.na(anchor[[2]])){
         if (x$format < 4){
             b0a0 <- settings('iratio','Pb207Pb206')[1]
@@ -192,9 +190,9 @@ get.ta0b0.model2 <- function(x,anchor=list(FALSE,NA)){
         intercept <- b0a0
         xyfit <- stats::lm(I(xy[,'Y']-intercept) ~ 0 + xy[,'X'])
         slope <- xyfit$coef
-        ta0b0 <- concordia.intersection.ab(intercept,slope,wetherill=FALSE)$x
+        ta0b0 <- concordia.intersection.ab(intercept,slope,wetherill=FALSE,d=x$d)
     } else if (is.numeric(anchor[[2]])){
-        TW <- age_to_terawasserburg_ratios(anchor[[2]],st=0,exterr=FALSE)
+        TW <- age_to_terawasserburg_ratios(anchor[[2]],st=0,exterr=FALSE,d=x$d)
         xyfit <- stats::lm(I(xy[,'Y']-TW$x['Pb207Pb206']) ~
                            0 + I(xy[,'X']-TW$x['U238Pb206']))
         slope <- xyfit$coef
@@ -226,29 +224,24 @@ get.ta0b0.model2 <- function(x,anchor=list(FALSE,NA)){
     ta0b0
 }
 get.ta0b0.model3 <- function(x,init,exterr=FALSE,anchor=list(FALSE,NA)){
-    fit <- fit_ludwig_discordia(x,init=init,w=0,exterr=exterr,
-                                fixed=fixit(x,anchor))
-    ta0b0 <- fit$par
-    w <- get_ludwig_disp(ta0b0,x,interval=get_lud_wrange(ta0b0,x))
-    out <- fit_ludwig_discordia(x,init=ta0b0,w=w,exterr=exterr,
-                                fixed=fixit(x,anchor))
-    out$w <- w
+    out <- list(w=0,par=init)
+#    for (i in 1:5){ # loop for more accurate but slower and more unstable results
+        out <- fit_ludwig_discordia(x,init=out$par,w=out$w,exterr=exterr,anchor=anchor)
+        out$w <- stats::optimize(LL.lud.disp,interval=c(0,1),x=x,ta0b0=out$par,
+                                 exterr=exterr,anchor=anchor,maximum=TRUE)$maximum
+#    }
     out
 }
-fit_ludwig_discordia <- function(x,init,w=0,exterr=FALSE,...){
-    optifix(parms=init,fn=LL.lud.UPb,method="BFGS",x=x,
-            w=w,exterr=exterr,...)
+fit_ludwig_discordia <- function(x,init,w=0,exterr=FALSE,anchor=list(FALSE,NA),...){
+    optifix(parms=init,fn=LL.lud.UPb,method="BFGS",x=x,w=w,
+            exterr=exterr,fixed=fixit(x,anchor))
 }
-get_ludwig_disp <- function(ta0b0,x,interval){
-    stats::optimize(LL.lud.UPb.disp,interval=interval,
-                    x=x,ta0b0=ta0b0,maximum=TRUE)$maximum
-}
-get_lud_wrange <- function(ta0b0,x){
-    c(0,1)
-}    
 
-LL.lud.UPb.disp <- function(w,x,ta0b0){
-    LL.lud.UPb(ta0b0,x=x,exterr=FALSE,w=w,LL=TRUE)
+LL.lud.disp <- function(w,x,ta0b0,exterr=FALSE,anchor=list(FALSE,NA)){
+    # these two lines produce slightly more accurate but much slower results:
+    # fit <- fit_ludwig_discordia(x,init=ta0b0,w=w,exterr=exterr,anchor=anchor)
+    # LL.lud.UPb(ta0b0=fit$par,x=x,exterr=exterr,w=w,LL=TRUE)
+    LL.lud.UPb(ta0b0=ta0b0,x=x,exterr=exterr,w=w,LL=TRUE)
 }
 LL.lud.UPb <- function(ta0b0,x,exterr=FALSE,w=0,LL=FALSE){
     if (x$format<4){
@@ -258,25 +251,24 @@ LL.lud.UPb <- function(ta0b0,x,exterr=FALSE,w=0,LL=FALSE){
     }
 }
 LL.lud.2D <- function(ta0,x,exterr=FALSE,w=0,LL=FALSE){
-    d <- data2ludwig(x,tt=ta0[1],a0=ta0[2],exterr=exterr,w=w)
-    R <- rbind(d$rx,d$ry)
-    out <- t(R) %*% d$omega %*% R
+    l <- data2ludwig(x,tt=ta0[1],a0=ta0[2],exterr=exterr,w=w)
+    R <- rbind(l$rx,l$ry)
+    out <- t(R) %*% l$omega %*% R
     if (LL){
         k <- length(R)
         out <- -0.5*(out + k*log(2*pi) +
-                     determinant(2*pi*d$omegainv,logarithm=TRUE)$modulus)
+                     determinant(2*pi*l$omegainv,logarithm=TRUE)$modulus)
     }
     out
 }
 LL.lud.3D <- function(ta0b0,x,exterr=FALSE,w=0,LL=FALSE){
-    d <- data2ludwig(x,tt=ta0b0[1],a0=ta0b0[2],
-                     b0=ta0b0[3],exterr=exterr,w=w)
-    phi <- d$phi
-    R <- d$R
-    r <- d$r
+    l <- data2ludwig(x,tt=ta0b0[1],a0=ta0b0[2],b0=ta0b0[3],exterr=exterr,w=w)
+    phi <- l$phi
+    R <- l$R
+    r <- l$r
     out <- 0
-    ns <- length(d$R)
-    omega <- d$omega
+    ns <- length(l$R)
+    omega <- l$omega
     for (i in 1:ns){
         i1 <- i
         i2 <- i + ns
@@ -294,7 +286,7 @@ LL.lud.3D <- function(ta0b0,x,exterr=FALSE,w=0,LL=FALSE){
     if (LL){
         k <- 2*ns
         out <- -0.5*(out + k*log(2*pi) +
-                     determinant(d$omegainv,logarithm=TRUE)$modulus)
+                     determinant(l$omegainv,logarithm=TRUE)$modulus)
     }
     out
 }
@@ -303,8 +295,7 @@ fisher.lud <- function(x,...){ UseMethod("fisher.lud",x) }
 fisher.lud.default <- function(x,...){
     stop( "No default method available (yet)." )
 }
-fisher.lud.UPb <- function(x,fit,exterr=TRUE,
-                           anchor=list(FALSE,NA),...){
+fisher.lud.UPb <- function(x,fit,exterr=TRUE,anchor=list(FALSE,NA),...){
     ns <- length(x)
     if (x$format<4){
         fish <- fisher_lud_2D(x,fit)
@@ -342,45 +333,43 @@ anchorfish <- function(AA,BB,CC,DD,anchor){
 fisher_lud_2D <- function(x,fit){
     tt <- fit$par[1]
     a0 <- fit$par[2]
-    d <- data2ludwig_2D(x,tt=tt,a0=a0,w=0,exterr=fit$exterr)
+    l <- data2ludwig_2D(x,tt=tt,a0=a0,w=0,exterr=fit$exterr)
     l5 <- settings('lambda','U235')[1]
     l8 <- settings('lambda','U238')[1]
     U <- settings('iratio','U238U235')[1]
     ns <- length(x)
     ones <- matrix(1,ns,1)
-    B <-  (exp(l5*tt)-1)/U - a0*(exp(l8*tt)-1)
-    C <- -t(d$X)%*%d$omega12 + t(d$x)%*%d$omega12 + t(d$x)%*%d$omega21 -
-        t(d$Y)%*%d$omega22 + t(ones)%*%d$omega22*a0 + 2*t(d$x)%*%d$omega22*B
-    D <- -t(d$X)%*%d$omega12%*%d$x + t(d$x)%*%d$omega12%*%d$x -
-        t(d$Y)%*%d$omega22%*%d$x + t(ones)%*%d$omega22%*%d$x*a0 -
-        t(d$x)%*%d$omega21%*%d$X + t(d$x)%*%d$omega21%*%d$x -
-        t(d$x)%*%d$omega22%*%d$Y + t(d$x)%*%d$omega22%*%ones*a0 +
-        2*t(d$x)%*%d$omega22%*%d$x*B
-    dBdt <- l5*exp(l5*tt)/U - a0*exp(l8*tt)*l8
-    dBda0 <- -(exp(l8*tt)-1)
-    d2Bdtda0 <- exp(l8*tt)*l8
-    d2Bda0dt <- exp(l8*tt)*l8
-    d2Bdt2 <- (l5^2)*exp(l5*tt)/U - a0*exp(l8*tt)*(l8^2)
+    D <- wendt(tt,d=x$d)
+    BB <- (exp(l5*tt)-1+D$d1)/U - a0*(exp(l8*tt)-1+D$d2)
+    CC <- -t(l$X)%*%l$omega12 + t(l$x)%*%l$omega12 + t(l$x)%*%l$omega21 -
+        t(l$Y)%*%l$omega22 + t(ones)%*%l$omega22*a0 + 2*t(l$x)%*%l$omega22*BB
+    DD <- -t(l$X)%*%l$omega12%*%l$x + t(l$x)%*%l$omega12%*%l$x -
+        t(l$Y)%*%l$omega22%*%l$x + t(ones)%*%l$omega22%*%l$x*a0 -
+        t(l$x)%*%l$omega21%*%l$X + t(l$x)%*%l$omega21%*%l$x -
+        t(l$x)%*%l$omega22%*%l$Y + t(l$x)%*%l$omega22%*%ones*a0 +
+        2*t(l$x)%*%l$omega22%*%l$x*BB
+    dBdt <- (l5*exp(l5*tt)+D$dd1dt)/U - a0*(l8*exp(l8*tt)+D$dd2dt)
+    dBda0 <- -(exp(l8*tt)-1+D$d2)
+    d2Bda0dt <- -(l8*exp(l8*tt)+D$dd2dt)
+    d2Bdtda0 <- d2Bda0dt
+    d2Bdt2 <- (l5*l5*exp(l5*tt)+D$d2d1dt2)/U - a0*(l8*l8*exp(l8*tt)+D$d2d2dt2)
     d2Bda02 <- 0
-    dDda0 <- t(ones)%*%d$omega22%*%d$x +
-        t(d$x)%*%d$omega22%*%ones + 2*t(d$x)%*%d$omega22%*%d$x*dBda0
+    dDda0 <- t(ones)%*%l$omega22%*%l$x +
+        t(l$x)%*%l$omega22%*%ones + 2*t(l$x)%*%l$omega22%*%l$x*dBda0
     ns <- length(x)
     out <- matrix(0,ns+2,ns+2)
     out[1:ns,1:ns] <- # d2S/dx2
-        2*(d$omega11 + d$omega21*B + d$omega12*B + d$omega22*B^2)
-
+        2*(l$omega11 + l$omega21*BB + l$omega12*BB + l$omega22*BB^2)
     out[ns+2,1:ns] <-   # d2S/dxda0
-        2*(C*dBda0 + t(ones)%*%d$omega21 + t(ones)%*%d$omega22*B)
+        2*(CC*dBda0 + t(ones)%*%l$omega21 + t(ones)%*%l$omega22*BB)
     out[ns+2,ns+2] <- # d2S/da02
-        2*(t(ones)%*%d$omega22%*%ones +
-           t(ones)%*%d$omega22%*%d$x*dBda0 +
-           t(d$x)%*%d$omega22%*%ones*dBda0 +
-           t(d$x)%*%d$omega22%*%d$x*(dBda0^2))
-    out[ns+1,1:ns] <- 2*C*dBdt # d2S/dxdt
+        2*(t(ones)%*%l$omega22%*%ones + t(ones)%*%l$omega22%*%l$x*dBda0 +
+           t(l$x)%*%l$omega22%*%ones*dBda0 + t(l$x)%*%l$omega22%*%l$x*(dBda0^2))
+    out[ns+1,1:ns] <- 2*CC*dBdt # d2S/dxdt
     out[ns+1,ns+1] <- # d2S/dt2
-        D*d2Bdt2 + 2*t(d$x)%*%d$omega22%*%d$x*(dBdt^2)
+        DD*d2Bdt2 + 2*t(l$x)%*%l$omega22%*%l$x*(dBdt^2)
     out[ns+1,ns+2] <- # d2S/dt0da0
-        D*d2Bdtda0 + dDda0*dBdt
+        DD*d2Bdtda0 + dDda0*dBdt
     out[1:ns,ns+1] <- t(out[ns+1,1:ns]) # d2S/dtdx
     out[1:ns,ns+2] <- t(out[ns+2,1:ns]) # d2S/da0dx
     out[ns+2,ns+1] <- out[ns+1,ns+2]
@@ -390,9 +379,9 @@ fisher_lud_3D <- function(x,fit){
     tt <- fit$par[1]
     a0 <- fit$par[2]
     b0 <- fit$par[3]
-    d <- data2ludwig_3D(x,tt=tt,a0=a0,b0=b0,w=0,exterr=fit$exterr)
-    z <- d$z
-    omega <- d$omega
+    l <- data2ludwig_3D(x,tt=tt,a0=a0,b0=b0,w=0,exterr=fit$exterr)
+    z <- l$z
+    omega <- l$omega
     ns <- length(z)
     l5 <- settings('lambda','U235')
     l8 <- settings('lambda','U238')
@@ -472,7 +461,7 @@ data2ludwig <- function(x,...){ UseMethod("data2ludwig",x) }
 data2ludwig.default <- function(x,...){ stop('default function undefined') }
 data2ludwig.UPb <- function(x,tt,a0,b0=0,exterr=FALSE,w=0,...){
     if (x$format<4)
-        out <- data2ludwig_2D(x,tt=tt,a0=a0,w=w,exterr=exterr)  
+        out <- data2ludwig_2D(x,tt=tt,a0=a0,w=w,exterr=exterr)
     else
         out <- data2ludwig_3D(x,tt=tt,a0=a0,b0=b0,w=w,exterr=exterr)
     out
@@ -482,15 +471,18 @@ data2ludwig_2D <- function(x,tt,a0,w=0,exterr=FALSE){
     l8 <- settings('lambda','U238')
     U <- settings('iratio','U238U235')[1]
     ns <- length(x)
-    B <-  (exp(l5[1]*tt)-1)/U - a0*(exp(l8[1]*tt)-1)
-    dBdl5 <- tt*exp(l5[1]*tt)/U
-    dBdl8 <- -a0*tt*exp(l8[1]*tt)
+    D <- wendt(tt=tt,d=x$d)
+    f1 <- exp(l5[1]*tt)-1 + D$d1
+    f2 <- exp(l8[1]*tt)-1 + D$d2
+    B <-  f1/U - a0*f2
+    dBdl5 <- (tt*exp(l5[1]*tt)+D$dd1dl5)/U
+    dBdl8 <- -a0*(tt*exp(l8[1]*tt)+D$dd2dl8)
     E <- matrix(0,2*ns+2,2*ns+2)
     J <- matrix(0,2*ns,2*ns+2)
     X <- matrix(0,ns,1)
     Y <- matrix(0,ns,1)
     for (i in 1:ns){
-        XY <- tera.wasserburg(x,i,exterr=FALSE)
+        XY <- tera.wasserburg(x,i)
         X[i] <- XY$x['U238Pb206']
         Y[i] <- XY$x['Pb207Pb206']
         E[(2*i-1):(2*i),(2*i-1):(2*i)] <- XY$cov
@@ -504,21 +496,23 @@ data2ludwig_2D <- function(x,tt,a0,w=0,exterr=FALSE){
     }
     E[2*ns+1,2*ns+1] <- l5[2]^2
     E[2*ns+2,2*ns+2] <- l8[2]^2
-    ER <- J %*% E %*% t(J)
     out <- list()
-    omega <- solve(ER)
-    omega11 <- omega[1:ns,1:ns]
-    omega12 <- omega[1:ns,(ns+1):(2*ns)]
-    omega21 <- omega[(ns+1):(2*ns),1:ns]
-    omega22 <- omega[(ns+1):(2*ns),(ns+1):(2*ns)]
-    out$x <- solve(omega11 + B*(omega12+omega21) + omega22*B^2) %*%
-        (omega11%*%X + B*omega12%*%X + omega21%*%(Y-a0) + B*omega22%*%(Y-a0))
-    out$omegainv <- ER
-    out$omega <- omega
-    out$omega11 <- omega11
-    out$omega12 <- omega12
-    out$omega21 <- omega21
-    out$omega22 <- omega22
+    OI <- J %*% E %*% t(J)
+    O <- blockinverse(AA=OI[1:ns,1:ns],
+                      BB=OI[1:ns,(ns+1):(2*ns)],
+                      CC=OI[(ns+1):(2*ns),1:ns],
+                      DD=OI[(ns+1):(2*ns),(ns+1):(2*ns)],
+                      doall=TRUE)
+    out$omegainv <- OI
+    out$omega <- O
+    out$omega11 <- O[1:ns,1:ns]
+    out$omega12 <- O[1:ns,(ns+1):(2*ns)]
+    out$omega21 <- O[(ns+1):(2*ns),1:ns]
+    out$omega22 <- O[(ns+1):(2*ns),(ns+1):(2*ns)]
+    left <- out$omega11 + B*(out$omega12+out$omega21) + out$omega22*B^2
+    right <- out$omega11%*%X + B*out$omega12%*%X +
+        out$omega21%*%(Y-a0) + B*out$omega22%*%(Y-a0)
+    out$x <- solve(left,right)
     out$X <- X
     out$Y <- Y
     out$rx <- X - out$x
@@ -530,33 +524,30 @@ data2ludwig_3D <- function(x,tt,a0,b0,w=0,exterr=FALSE){
     l8 <- settings('lambda','U238')
     U <- settings('iratio','U238U235')[1]
     ns <- length(x)
+    E <- matrix(0,3*ns+2,3*ns+2)
+    J <- matrix(0,3*ns,3*ns+2)
     R <- rep(0,ns)
     r <- rep(0,ns)
     Z <- rep(0,ns)
-    E <- matrix(0,3*ns,3*ns)
-    if (exterr){
-        P235 <- tt*exp(l5[1]*tt)
-        P238 <- tt*exp(l8[1]*tt)
-        E[1:ns,1:ns] <- (P235*l5[2])^2 # A
-        E[(ns+1):(2*ns),(ns+1):(2*ns)] <- (P238*l8[2])^2 # B
-    }
+    D <- wendt(tt=tt,d=x$d)
     for (i in 1:ns){
-        d <- wetherill(x,i=i,exterr=FALSE)
-        Z[i] <- d$x['Pb204U238']
-        R[i] <- d$x['Pb207U235'] - exp(l5[1]*tt) + 1 - U*b0*Z[i]
-        r[i] <- d$x['Pb206U238'] - exp(l8[1]*tt) + 1 - a0*Z[i]
+        wd <- wetherill(x,i=i)
+        Z[i] <- wd$x['Pb204U238']
+        R[i] <- wd$x['Pb207U235'] - exp(l5[1]*tt) + 1 - U*b0*Z[i] - D$d1
+        r[i] <- wd$x['Pb206U238'] - exp(l8[1]*tt) + 1 - a0*Z[i] - D$d2
         Ew <- get.Ew(w=w,Z=Z[i],a0=a0,b0=b0,U=U)
-        E[i,i] <- E[i,i] + d$cov['Pb207U235','Pb207U235'] + Ew[1,1] # A
-        E[ns+i,ns+i] <- E[ns+i,ns+i] + d$cov['Pb206U238','Pb206U238'] + Ew[2,2] # B
-        E[2*ns+i,2*ns+i] <- d$cov['Pb204U238','Pb204U238'] # C
-        E[i,ns+i] <- d$cov['Pb207U235','Pb206U238'] + Ew[1,2] # D
-        E[ns+i,i] <- E[i,ns+i] + Ew[2,1]
-        E[i,2*ns+i] <- d$cov['Pb207U235','Pb204U238'] # E
-        E[2*ns+i,i] <- E[i,2*ns+i]
-        E[ns+i,2*ns+i] <- d$cov['Pb206U238','Pb204U238'] # F
-        E[2*ns+i,ns+i] <- E[ns+i,2*ns+i]
+        E[(3*i-2):(3*i),(3*i-2):(3*i)] <- wd$cov + Ew
+        J[i,3*i-2] <- 1                                  # dRdX
+        J[ns+i,3*i-1] <- 1                               # drdY
+        J[2*ns+i,3*i] <- 1                               # dphidZ
+        if (exterr){
+            J[i,3*ns+1] <- -tt*exp(l5[1]*tt) - D$dd1dl5    # dRdl5
+            J[ns+i,3*ns+2] <- -tt*exp(l8[1]*tt) - D$dd2dl8 # drdl8
+        }
     }
-    omega <- solve(E)
+    E[3*ns+1,3*ns+1] <- l5[2]^2
+    E[3*ns+2,3*ns+2] <- l8[2]^2
+    omega <- solve(J %*% E %*% t(J))
     # rearrange sum of squares:
     V <- matrix(0,ns,ns)
     W <- rep(0,ns)
@@ -577,18 +568,13 @@ data2ludwig_3D <- function(x,tt,a0,b0,w=0,exterr=FALSE){
     }
     phi <- solve(V,W)
     z <- Z - phi
-    out <- list(R=R,r=r,phi=phi,z=z,omega=omega,omegainv=E)
+    out <- list(R=R,r=r,phi=phi,z=z,omega=omega,omegainv=E)    
 }
 get.Ew <- function(w,Z,a0,b0,U){
-    J <- matrix(0,2,4)
-    J[1,1] <- Z*U
-    J[1,3] <- a0*U
-    J[1,4] <- a0*Z
-    J[2,2] <- Z
-    J[2,3] <- b0
-    E <- matrix(0,4,4)
-    E[1,1] <- (a0*w)^2
-    E[2,2] <- (b0*w)^2
+    E <- diag(c(a0,b0)*w)^2
+    J <- matrix(0,3,2)
+    J[1,2] <- -U*Z # dRda0
+    J[2,1] <- -Z   # dRdb0
     J %*% E %*% t(J)
 }
 
