@@ -85,7 +85,7 @@ titterington <- function(x,alpha=0.05){
     covmat <- solve(fish)
     out <- list()
     out$par <- fit$par
-    out$cov <- covmat[(ns-3):ns,(ns-3):ns]
+    out$cov <- covmat[(ns+1):(ns+4),(ns+1):(ns+4)]
     mswd <- mswd.tit(fit$par,dat)
     out <- c(out,mswd)
     parnames <- c('a','b','A','B')
@@ -186,13 +186,13 @@ fisher.tit <- function(abAB,dat){
         d2L.dadB <- d2L.dadB - x*omega[2,3]
         d2L.dbdA <- d2L.dbdA - x*omega[2,3]
         d2L.dbdB <- d2L.dbdB - omega[2,3]*x^2
-    }
-    for (i in 1:ns){
-        omega <- dat$omega[[i]]
+        
         d2L.dadx <- -(omega[1,2] + b*omega[2,2] + B*omega[2,3])
-        d2L.dbdx <- -x*(omega[1,2] + b*omega[2,2] + B*omega[2,3])
+        d2L.dbdx <- -x*(omega[1,2] + b*omega[2,2] + B*omega[2,3]) +
+            omega[2,2]*(Y-a-b*x) + omega[1,2]*(X-x) + omega[2,3]*(Z-A-B*x)
         d2L.dAdx <- -(omega[1,3] + b*omega[2,3] + B*omega[3,3])
-        d2L.dBdx <- -x*(omega[1,3] + b*omega[2,3] + B*omega[3,3])
+        d2L.dBdx <- -x*(omega[1,3] + b*omega[2,3] + B*omega[3,3]) +
+            omega[2,3]*(Y-a-b*x) + omega[1,3]*(X-x) + omega[3,3]*(Z-A-B*x)
         d2L.dx2 <- -(omega[1,1] + 2*b*omega[1,2] + 2*B*omega[1,3] +
                      omega[2,2]*b^2 + omega[2,3]*B^2 + 2*omega[3,3]*b*B)
         out[i,i] <- -d2L.dx2
